@@ -35,6 +35,7 @@
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-client.h>
+#include <string.h>
 #include <stdlib.h>
 
 #include "GNOME_Yelp.h"
@@ -58,7 +59,9 @@ struct poptOption options[] = {
 		NULL,
 		NULL,
 	},
-	NULL
+	{
+		NULL
+	}
 };
 
 static BonoboObject * main_base_factory       (BonoboGenericFactory *factory,
@@ -265,7 +268,6 @@ main (int argc, char **argv)
 	gchar        *url = NULL;
 	GnomeClient  *client;
 	gboolean      flag = FALSE;
-	gboolean      gman = FALSE;
 	
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);  
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -309,13 +311,17 @@ main (int argc, char **argv)
 		flag = TRUE;
         }
 
-	if (!factory) {
-		BonoboGenericFactory   *factory;
-		/* Not started, start now */
+	if (!factory) { /* Not started, start now */ 
+		BonoboGenericFactory *factory;
+		char                 *registration_id;
 
-		factory = bonobo_generic_factory_new (YELP_FACTORY_OAFIID,
+		registration_id = bonobo_activation_make_registration_id (
+					YELP_FACTORY_OAFIID,
+					gdk_display_get_name (gdk_display_get_default ()));
+		factory = bonobo_generic_factory_new (registration_id,
 						      main_base_factory,
 						      NULL);
+		g_free (registration_id);
 
 		bonobo_running_context_auto_exit_unref (BONOBO_OBJECT (factory));
         
